===============================
Regressors
===============================

.. image:: https://img.shields.io/pypi/v/regressors.svg
        :target: https://pypi.python.org/pypi/regressors

.. image:: https://img.shields.io/travis/nsh87/regressors.svg
        :target: https://travis-ci.org/nsh87/regressors

.. image:: https://readthedocs.org/projects/regressors/badge/?version=latest
        :target: https://readthedocs.org/projects/regressors/?badge=latest
        :alt: Documentation Status


Easy utilities for fitting various regressors, extracting stats, and making relevant plots

* Free software: ISC license
* Documentation: https://regressors.readthedocs.org.

Features
--------

* TODO

Credits
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-pypackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
